@@ -17,12 +17,16 @@ import Prelude        ()
 import Prelude.Compat
 
 import Data.Aeson.Compat
-import Data.Aeson.Types  hiding ((.:?))
-import Data.Text         (Text)
 import Data.Time         (UTCTime, ZonedTime)
 import Data.Typeable     (Typeable)
 
 #if !MIN_VERSION_aeson (0,10,0)
+import Data.Text         (Text)
+
+#if !MIN_VERSION_aeson_compat(0,3,5)
+import           Data.Aeson.Types (Parser)
+#endif
+
 import qualified Data.Time.Parsers as TimeParsers
 import qualified Text.Parsec       as Parsec
 #endif
